'use client';

import { useAuth } from '@/components/context';
import { useRouter } from 'next/navigation';
import { useEffect } from 'react';
import { Loader2 } from 'lucide-react';

const AuthSuccessPage = () => {
  const { refreshUserData } = useAuth();
  const router = useRouter();

  useEffect(() => {
    const handleAuthSuccess = async () => {
      // Refresh the auth context to pick up the new session
      await refreshUserData();

      // Small delay to ensure state is updated
      setTimeout(() => {
        router.push('/');
      }, 100);
    };

    handleAuthSuccess().catch((error) => {
      console.error(`Error: ${error instanceof Error ? error.message : error}`);
    });
  }, [refreshUserData, router]);

  // Show loading while processing
  return (
    <div className='flex items-center justify-center min-h-screen'>
      <div className='flex flex-col items-center space-y-4'>
        <Loader2 className='h-8 w-8 animate-spin' />
        <p>Completing sign in...</p>
      </div>
    </div>
  );
};

export default AuthSuccessPage;
